==> optimizers_af-0.0.1.tar.gz: optimizers_af-0.0.1/README.md <==
# optimizers_af

![GitHub repo size](https://img.shields.io/github/repo-size/AlbertFarkhutdinov/optimizers_af)
![PyPI version](https://img.shields.io/pypi/v/optimizers_af)
![GitHub contributors](https://img.shields.io/github/contributors/AlbertFarkhutdinov/optimizers_af)
![GitHub forks](https://img.shields.io/github/forks/AlbertFarkhutdinov/optimizers_af?style=social)
![GitHub licence](https://img.shields.io/github/license/AlbertFarkhutdinov/optimizers_af)

`optimizers_af` provides functions for optimizing objective functions.

## Prerequisites

Before you begin, ensure you have installed the latest version of Python.

## Installing `optimizers_af`

To install `optimizers_af`, follow these steps:

Linux and macOS:
```
pip3 install optimizers_af
```

Windows:
```
pip install optimizers_af
```
## Using `optimizers_af`

There are will be examples of how to use `optimizers_af`.

## Contributing to `optimizers_af`
To contribute to `optimizers_af`, follow these steps:

1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively see the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## Contributors

* [@AlbertFarkhutdinov](https://github.com/AlbertFarkhutdinov) 

## Contact

If you want to contact me you can reach me at `albertfarhutdinov@gmail.com`.

## License
This project uses the following license: [MIT License](https://github.com/AlbertFarkhutdinov/optimizers_af/blob/main/LICENSE).

==> optimizers_af-0.0.3.tar.gz: optimizers_af-0.0.3/README.md <==
# optimizers_af

![GitHub repo size](https://img.shields.io/github/repo-size/AlbertFarkhutdinov/optimizers_af)
![PyPI version](https://img.shields.io/pypi/v/optimizers-af)
![GitHub contributors](https://img.shields.io/github/contributors/AlbertFarkhutdinov/optimizers_af)
![GitHub forks](https://img.shields.io/github/forks/AlbertFarkhutdinov/optimizers_af?style=social)
![GitHub licence](https://img.shields.io/github/license/AlbertFarkhutdinov/optimizers_af)

`optimizers_af` provides functions for optimizing objective functions.

## Prerequisites

Before you begin, ensure you have installed the latest version of Python.

## Installing `optimizers_af`

To install `optimizers_af`, follow these steps:

Linux and macOS:
```
pip3 install optimizers-af
```

Windows:
```
pip install optimizers-af
```
## Using `optimizers_af`

There are will be examples of how to use `optimizers_af`.

## Contributing to `optimizers_af`
To contribute to `optimizers_af`, follow these steps:

1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively see the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## Contributors

* [@AlbertFarkhutdinov](https://github.com/AlbertFarkhutdinov) 

## Contact

If you want to contact me you can reach me at `albertfarhutdinov@gmail.com`.

## License
This project uses the following license: [MIT License](https://github.com/AlbertFarkhutdinov/optimizers_af/blob/main/LICENSE).
